Thread (2 messages) 2 messages, 2 authors, 2015-07-19

Re: [PATCH v3] jhash: Deinline jhash and jhash2

flat view

From: David Miller <davem@davemloft.net>
Date: 2015-07-19 18:41:24
Also in: lkml

From: Denys Vlasenko <redacted>
Date: Sun, 19 Jul 2015 17:36:00 +0200
This patch deinlines jhash and jhash2.

It also removes rhashtable_jhash2(key, length, seed)
because it was merely calling jhash2(key, length, seed).

With this .config: http://busybox.net/~vda/kernel_config,
after deinlining these functions have sizes and callsite counts
as follows:

jhash: 297 bytes, 111 calls
jhash2: 205 bytes, 136 calls

Total size decrease is about 33,000 bytes:

    text     data      bss       dec     hex filename
90663567 17221960 36659200 144544727 89d93d7 vmlinux5
90630370 17221864 36659200 144511434 89d11ca vmlinux.after

Signed-off-by: Denys Vlasenko <redacted>
No performance metrics at all have been provided, so this should
not be applied.
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help